@@ -17,5 +17,26 @@
 	along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
 
+#include <stdlib.h>
+#include <stdio.h>
+
 #define PACKAGE "pev"
-#define VERSION "0.31"
+#define VERSION "0.40"
+
+#define PE32 0x10b
+#define PE64 0x20b
+#define ROM 0x107
+
+#ifdef __DEBUG_MODE__
+	#define EXIT_WITH_ERROR(msg) \
+			{ \
+				fprintf(stderr, "%s, %d: %s\n", __FILE__, __LINE__, msg); \
+				exit(EXIT_FAILURE); \
+			}
+#else
+	#define EXIT_WITH_ERROR(msg) \
+			{ \
+				fprintf(stderr, "%s: %s\n", PACKAGE, msg); \
+				exit(EXIT_FAILURE); \
+			}
+#endif
